@@ -6,6 +6,8 @@
 ( cd opt/kde/share/doc/HTML/et/kdm ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kig ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kig ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/juk ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpf ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ktuberling ; rm -rf common )
@@ -26,6 +28,10 @@
 ( cd opt/kde/share/doc/HTML/et/kgpg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmag ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kmag ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kmid ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kmid ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kmix ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kmix ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kodo ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kolf ; rm -rf common )
@@ -40,6 +46,8 @@
 ( cd opt/kde/share/doc/HTML/et/kppp ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/krdc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/krdc ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/krec ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/krec ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/krfb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/krfb ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kscd ; rm -rf common )
@@ -144,16 +152,22 @@
 ( cd opt/kde/share/doc/HTML/et/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kompare ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kompmgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kompmgr ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kontact ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kontact ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konsole ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konsolekalendar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kanagram ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kanagram ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpackage ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/lilo-config ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/lilo-config ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/khelpcenter/quickstart ; rm -rf common )
@@ -170,6 +184,8 @@
 ( cd opt/kde/share/doc/HTML/et/kshisen ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksirtet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksirtet ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kdesvn-build ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kdesvn-build ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konquest ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/akregator ; rm -rf common )
@@ -202,110 +218,6 @@
 ( cd opt/kde/share/doc/HTML/et/knetattach ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf fdl-license )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/fdl-license fdl-license )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf qpl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf x11-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 1.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/1.png 1.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf xml.dcl )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 2.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/2.png 2.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 3.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/3.png 3.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 4.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/4.png 4.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 5.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/5.png 5.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 6.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/6.png 6.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 7.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/7.png 7.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 8.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/8.png 8.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 9.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/9.png 9.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf headerbg.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf gpl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf mainheader.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf grad.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/grad.png grad.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-web.css )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf lgpl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf doxygen.css )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf web-doctop.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-default.css )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf kmenu.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf footer.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/footer.html footer.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-common.css )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom-left.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf appheader.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/appheader.html appheader.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop1.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop2.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf shadow.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/shadow.png shadow.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde_logo.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf docheadergears.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf top-middle.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf fdl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom-right.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop1a.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf 10.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/10.png 10.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop1b.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf lgpl-license )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf mainfooter.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom1.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom2.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf header.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/header.html header.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom-middle.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf top-left.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/top-left.png top-left.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf gpl-license )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/gpl-license gpl-license )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf bsd-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf web-docbottom.png )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
-( cd opt/kde/share/doc/HTML/et/common ; rm -rf artistic-license.html )
-( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
 ( cd opt/kde/share/doc/HTML/et/multisynk ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/multisynk ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kdm ; rm -rf common )
@@ -416,6 +328,8 @@
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kcontrol/performance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konq-plugins/crashes ; rm -rf common )
@@ -452,6 +366,8 @@
 ( cd opt/kde/share/doc/HTML/et/kalarm ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kamera ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kaudiocreator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kaudiocreator ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kdeprint ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kasteroids ; rm -rf common )
@@ -464,6 +380,8 @@
 ( cd opt/kde/share/doc/HTML/et/kgamma ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kdevelop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kdevelop ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kicker ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/klatin ; rm -rf common )
@@ -516,10 +434,16 @@
 ( cd opt/kde/share/doc/HTML/et/kcharselect ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/quanta ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/quanta ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/superkaramba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/superkaramba ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/ksmiletris ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/ksmiletris ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kuickshow ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kolourpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kde_app_devel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kommander ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kommander ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kiconedit ; rm -rf common )
@@ -540,6 +464,8 @@
 ( cd opt/kde/share/doc/HTML/et/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kgeography ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kgeography ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kleopatra ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kleopatra ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kjumpingcube ; rm -rf common )
@@ -550,6 +476,8 @@
 ( cd opt/kde/share/doc/HTML/et/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kworldclock ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/blinken ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/blinken ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksokoban ; rm -rf common )
@@ -558,6 +486,8 @@
 ( cd opt/kde/share/doc/HTML/et/kteatime ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmathtool ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kmathtool ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/knetworkconf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/pci ; rm -rf common )
@@ -582,6 +512,8 @@
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/partitions ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kinfocenter/cdinfo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kinfocenter/cdinfo ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/memory ; rm -rf common )
